Installation
============
If you are using pip, you can simply run ::

  pip install symfit

from your terminal. If you prefer to use `conda`, run ::

  conda install -c conda-forge symfit

instead. Lastly, if you prefer to install manually you can download
the source from https://github.com/tBuLi/symfit.

Contrib module
--------------
To also install the dependencies of 3rd party contrib modules such as
interactive guesses, install `symfit` using::

  pip install symfit[contrib]

Dependencies
------------
See `requirements.txt` for a full list.
